==> UPS-courier_v1.3.8.zip: UPS-courier v1.3.8/UPS-courier v1.3.8.oxp/Scripts/pirate_upsbase.js <==
/*this.name      = "pirate_upsbase"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.00";*/

this.shipSpawned = function() {this.piratebaseAdded();}
this.shipDied = function() {this.piratebaseKilled();}
this.beingAttacked = function() {this.piratebaseAttacked();}

this.piratebaseAdded = function()
{
    this.ReserveEnergy = this.ship.maxEnergy * missionVariables.ups_c2count * 0.25
    // make ship 25% stronger on every kill.
    delete this.shipSpawned;
    delete this.piratebaseAdded;
}

this.piratebaseKilled = function() 
{ 
    if(missionVariables.ups_container == "SEARCHING3" || missionVariables.ups_container == "JOINED_PIRATES" || missionVariables.ups_container == "JOINED_PIRATES2") missionVariables.ups_container = "FOUND3"
    if(missionVariables.ups_container == "SEARCHING4") missionVariables.ups_container = "FOUND4"
    missionVariables.TL_FOR_EQ_UPS_POLICE_SCANNER = null
    missionVariables.TL_FOR_EQ_UPS_IDCLEANER = null
    player.commsMessage("Next time we will have an even stronger base!", 6)
    if (missionVariables.ups_cloaking == "CRIPPLED") 
    { 
        player.removeEquipment("EQ_CRIPPLED_CLOAKING")
	player.awardEquipment("EQ_CLOAKING_DEVICE")
	missionVariables.ups_cloaking = "YES"
	player.consoleMessage("Cloaking ability restored", 4);
    }
    delete this.shipDied;
    delete this.piratebaseKilled;
}

this.piratebaseAttacked = function()
{ // bug with references in 1.70
    if(oolite.compareVersion("1.70") != 0 && this.ship.energy < this.ship.maxEnergy * 0.5 && this.ReserveEnergy > 0)
    {
        if (this.ReserveEnergy > 500)
        {
            this.ReserveEnergy -= 500
            this.ship.energy += 500
            player.commsMessage("You can shoot now, but we win at the end.", 6)
        }
        else
        {
            this.ship.energy += this.ReserveEnergy
            this.ReserveEnergy = 0
        }
    }
}

==> UPS-courier_v1.4.1.zip: UPS-courier v1.4.1/UPS-courier v1.4.1.oxp/Scripts/pirate_upsbase.js <==
this.name      = "pirate_upsbase"; 
this.author    = "eric walch"; 
this.copyright = " 2008 the Oolite team."; 
this.version   = "1.01";

this.shipSpawned = function()
{
    this.ReserveEnergy = this.ship.maxEnergy * missionVariables.ups_c2count * 0.25
    // make ship 25% stronger on every kill.
    delete this.shipSpawned;
}

this.shipDied = function() 
{ 
    if(missionVariables.ups_container == "SEARCHING3" || missionVariables.ups_container == "JOINED_PIRATES" || missionVariables.ups_container == "JOINED_PIRATES2") missionVariables.ups_container = "FOUND3"
    if(missionVariables.ups_container == "SEARCHING4") missionVariables.ups_container = "FOUND4"
    missionVariables.TL_FOR_EQ_UPS_POLICE_SCANNER = null
    missionVariables.TL_FOR_EQ_UPS_IDCLEANER = null
    player.commsMessage("Next time we will have an even stronger base!", 6)
    if (missionVariables.ups_cloaking == "CRIPPLED") 
    { 
        player.removeEquipment("EQ_CRIPPLED_CLOAKING")
	player.awardEquipment("EQ_CLOAKING_DEVICE")
	missionVariables.ups_cloaking = null
	player.consoleMessage("Cloaking ability restored", 4);
    }
    mission.setInstructionsKey("ups_containers_small4b", "ups_container")
    mission.unmarkSystem(missionVariables.ups_cplanet)

    delete this.shipDied;
}

this.shipBeingAttacked = function()
{
    if(this.ship.energy < this.ship.maxEnergy * 0.5 && this.ReserveEnergy > 0)
    {
        if (this.ReserveEnergy > 500)
        {
            this.ReserveEnergy -= 500
            this.ship.energy += 500
            player.commsMessage("You can shoot now, but we win at the end.", 6)
        }
        else
        {
            this.ship.energy += this.ReserveEnergy
            this.ReserveEnergy = 0
        }
    }
}
